@@ -1,6 +1,7 @@
 """Licensed under GPLv3, see https://www.gnu.org/licenses/"""
 
 import codecs
+import datetime
 import enum
 import os
 import shutil
@@ -9,12 +10,12 @@ import sys
 import tempfile
 from multiprocessing.pool import ThreadPool
 from time import sleep
-from typing import IO, TYPE_CHECKING, Any, Callable, Iterable, TypeVar
+from typing import IO, TYPE_CHECKING, Any, Callable, Final, TypeVar
 
 import pyalpm
 
 from .args import parse_args
-from .config import PikaurConfig
+from .config import _USER_TEMP_ROOT, RUNNING_AS_ROOT, PikaurConfig
 from .i18n import translate
 from .pprint import ColorsHighlight, bold_line, color_line, print_error, print_stderr
 
@@ -25,32 +26,33 @@ if TYPE_CHECKING:
     from .aur import AURPackageInfo
 
     class SpawnArgs(TypedDict):
-        stdout: NotRequired['IOStream']
-        stderr: NotRequired['IOStream']
+        stdout: NotRequired["IOStream"]
+        stderr: NotRequired["IOStream"]
         cwd: NotRequired[str]
         env: NotRequired[dict[str, str]]
 
-
-DEFAULT_INPUT_ENCODING = 'utf-8'
-PIPE = subprocess.PIPE
 IOStream = IO[bytes] | int | None
 
+DEFAULT_INPUT_ENCODING: Final = "utf-8"
+DEFAULT_TIMEZONE: Final = datetime.datetime.now().astimezone().tzinfo  # noqa: DTZ005
+PIPE: Final = subprocess.PIPE
+
 
 class ComparableType:
 
     __ignore_in_eq__: tuple[str, ...] = ()
 
     __hash__ = object.__hash__
-    __compare_stack__: list['ComparableType'] | None = None
+    __compare_stack__: list["ComparableType"] | None = None
 
     @property
     def public_values(self) -> dict[str, Any]:
         return {
             var: val for var, val in vars(self).items()
-            if not var.startswith('__')
+            if not var.startswith("__")
         }
 
-    def __eq__(self, other: 'ComparableType') -> bool:  # type: ignore[override]
+    def __eq__(self, other: "ComparableType") -> bool:  # type: ignore[override]
         if not isinstance(other, self.__class__):
             return False
         if not self.__compare_stack__:
@@ -68,7 +70,7 @@ class ComparableType:
                     del values[skip_prop]
         result = self_values == others_values
         self.__compare_stack__ = None
-        return result
+        return result  # noqa: RET504
 
 
 class DataType(ComparableType):
@@ -79,22 +81,24 @@ class DataType(ComparableType):
     def __all_annotations__(self) -> dict[str, type]:
         annotations: dict[str, type] = {}
         for parent_class in reversed(self.__class__.mro()):
-            annotations.update(**getattr(parent_class, '__annotations__', {}))
+            annotations.update(**getattr(parent_class, "__annotations__", {}))
         return annotations
 
     def _key_exists(self, key: str) -> bool:
         return key in dir(self)
 
-    def __init__(self, ignore_extra_properties: bool = False, **kwargs: Any) -> None:
+    def __init__(self, *, ignore_extra_properties: bool = False, **kwargs: Any) -> None:
         self.ignore_extra_properties = ignore_extra_properties
         for key, value in kwargs.items():
             setattr(self, key, value)
         for key in self.__all_annotations__:
             if not self._key_exists(key):
-                raise TypeError(
-                    f"'{self.__class__.__name__}' does "
-                    f"not have required attribute '{key}' set"
+                missing_required_attribute = translate(
+                    "'{class_name}' does not have required attribute '{key}' set."
+                ).format(
+                    class_name=self.__class__.__name__, key=key,
                 )
+                raise TypeError(missing_required_attribute)
 
     def __setattr__(self, key: str, value: Any) -> None:
         if not (
@@ -102,13 +106,15 @@ class DataType(ComparableType):
                 key in self.__all_annotations__
             ) or self._key_exists(key)
         ):
+            unknown_attribute = translate(
+                "'{class_name}' does not have attribute '{key}' defined."
+            ).format(
+                class_name=self.__class__.__name__, key=key,
+            )
             if self.ignore_extra_properties:
-                print_error(f"Unexpected key `{key}` in {self.__class__.__name__}")
+                print_error(unknown_attribute)
             else:
-                raise TypeError(
-                    f"'{self.__class__.__name__}' does "
-                    f"not have attribute '{key}'"
-                )
+                raise TypeError(unknown_attribute)
         super().__setattr__(key, value)
 
 
@@ -126,14 +132,14 @@ class InstallInfo(DataType):
     maintainer: str | None = None
     repository: str | None = None
     devel_pkg_age_days: int | None = None
-    package: 'pyalpm.Package | AURPackageInfo'
-    provided_by: list['pyalpm.Package | AURPackageInfo'] | None = None
-    required_by: list['InstallInfo'] | None = None
+    package: "pyalpm.Package | AURPackageInfo"
+    provided_by: list["pyalpm.Package | AURPackageInfo"] | None = None
+    required_by: list["InstallInfo"] | None = None
     members_of: list[str] | None = None
     replaces: list[str] | None = None
     pkgbuild_path: str | None = None
 
-    __ignore_in_eq__ = ('package', 'provided_by', 'pkgbuild_path')
+    __ignore_in_eq__ = ("package", "provided_by", "pkgbuild_path")
 
     @property
     def package_source(self) -> PackageSource:
@@ -144,16 +150,16 @@ class InstallInfo(DataType):
     def __repr__(self) -> str:
         return (
             f'<{self.__class__.__name__} "{self.name}" '
-            f'{self.current_version} -> {self.new_version}>'
+            f"{self.current_version} -> {self.new_version}>"
         )
 
 
 class RepoInstallInfo(InstallInfo):
-    package: 'pyalpm.Package'
+    package: "pyalpm.Package"
 
 
 class AURInstallInfo(InstallInfo):
-    package: 'AURPackageInfo'
+    package: "AURPackageInfo"
 
 
 def sudo(cmd: list[str]) -> list[str]:
@@ -164,23 +170,24 @@ def sudo(cmd: list[str]) -> list[str]:
 
 def get_sudo_refresh_command() -> list[str]:
     pacman_path = PikaurConfig().misc.PacmanPath.get_str()
-    return sudo([pacman_path, '-T'])
+    return sudo([pacman_path, "-T"])
 
 
 class InteractiveSpawn(subprocess.Popen[bytes]):
 
     stdout_text: str | None
     stderr_text: str | None
+    _terminated: bool = False
 
     def communicate(
             self, com_input: bytes | None = None, timeout: float | None = None
     ) -> tuple[bytes, bytes]:
-        if parse_args().print_commands:
+        if parse_args().print_commands and not self._terminated:
             if self.args != get_sudo_refresh_command():
                 print_stderr(
-                    color_line('=> ', ColorsHighlight.cyan) +
+                    color_line("=> ", ColorsHighlight.cyan) +
                     (
-                        ' '.join(str(arg) for arg in self.args)
+                        " ".join(str(arg) for arg in self.args)
                         if isinstance(self.args, list) else
                         str(self.args)
                     )
@@ -193,13 +200,14 @@ class InteractiveSpawn(subprocess.Popen[bytes]):
 
     def __repr__(self) -> str:
         return (
-            f'{self.__class__.__name__} returned {self.returncode}:\n'
-            f'STDOUT:\n{self.stdout_text}\n\n'
-            f'STDERR:\n{self.stderr_text}'
+            f"{self.__class__.__name__} returned {self.returncode}:\n"
+            f"STDOUT:\n{self.stdout_text}\n\n"
+            f"STDERR:\n{self.stderr_text}"
         )
 
     def __del__(self) -> None:
         self.terminate()
+        self._terminated = True
         self.communicate()
 
 
@@ -210,15 +218,15 @@ def interactive_spawn(
         cwd: str | None = None,
         env: dict[str, str] | None = None,
 ) -> InteractiveSpawn:
-    kwargs: 'SpawnArgs' = {}
+    kwargs: "SpawnArgs" = {}
     if stdout:
-        kwargs['stdout'] = stdout
+        kwargs["stdout"] = stdout
     if stderr:
-        kwargs['stderr'] = stderr
+        kwargs["stderr"] = stderr
     if cwd:
-        kwargs['cwd'] = cwd
+        kwargs["cwd"] = cwd
     if env:
-        kwargs['env'] = env
+        kwargs["env"] = env
     process = InteractiveSpawn(
         cmd, **kwargs
     )
@@ -260,7 +268,7 @@ def joined_spawn(
 
 
 def running_as_root() -> bool:
-    return os.geteuid() == 0
+    return RUNNING_AS_ROOT
 
 
 def isolate_root_cmd(
@@ -271,23 +279,23 @@ def isolate_root_cmd(
     if not running_as_root():
         return cmd
     base_root_isolator = [
-        '/usr/sbin/systemd-run',
-        '--service-type=oneshot',
-        '--pipe', '--wait', '--pty',
-        '-p', 'DynamicUser=yes',
-        '-p', 'CacheDirectory=pikaur',
-        '-E', 'HOME=/tmp',
+        "/usr/sbin/systemd-run",
+        "--service-type=oneshot",
+        "--pipe", "--wait", "--pty",
+        "-p", "DynamicUser=yes",
+        "-p", "CacheDirectory=pikaur",
+        "-E", f"HOME={_USER_TEMP_ROOT}",
     ]
     if env is not None:
         for env_var_name, env_var_value in env.items():
-            base_root_isolator += ['-E', f'{env_var_name}={env_var_value}']
+            base_root_isolator += ["-E", f"{env_var_name}={env_var_value}"]
     if cwd is not None:
-        base_root_isolator += ['-p', 'WorkingDirectory=' + os.path.abspath(cwd)]
+        base_root_isolator += ["-p", "WorkingDirectory=" + os.path.abspath(cwd)]
     for env_var_name in (
-            'http_proxy', 'https_proxy', 'ftp_proxy',
+            "http_proxy", "https_proxy", "ftp_proxy",
     ):
         if os.environ.get(env_var_name) is not None:
-            base_root_isolator += ['-E', f'{env_var_name}={os.environ[env_var_name]}']
+            base_root_isolator += ["-E", f"{env_var_name}={os.environ[env_var_name]}"]
     return base_root_isolator + cmd
 
 
@@ -296,25 +304,25 @@ def detect_bom_type(file_path: str) -> str:
     returns file encoding string for open() function
     https://stackoverflow.com/a/44295590/1850190
     """
-    with open(file_path, 'rb') as test_file:
+    with open(file_path, "rb") as test_file:
         first_bytes = test_file.read(4)
 
-    if first_bytes[0:3] == b'\xef\xbb\xbf':
+    if first_bytes[0:3] == b"\xef\xbb\xbf":
         return "utf-8"
 
     # Python automatically detects endianness if utf-16 bom is present
     # write endianness generally determined by endianness of CPU
     if (
-            first_bytes[0:2] == b'\xfe\xff'
+            first_bytes[0:2] == b"\xfe\xff"
     ) or (
-        first_bytes[0:2] == b'\xff\xfe'
+        first_bytes[0:2] == b"\xff\xfe"
     ):
         return "utf16"
 
     if (
-            first_bytes[0:5] == b'\xfe\xff\x00\x00'
+            first_bytes[0:5] == b"\xfe\xff\x00\x00"
     ) or (
-        first_bytes[0:5] == b'\x00\x00\xff\xfe'
+        first_bytes[0:5] == b"\x00\x00\xff\xfe"
     ):
         return "utf32"
 
@@ -325,16 +333,16 @@ def detect_bom_type(file_path: str) -> str:
 
 
 def open_file(
-        file_path: str, mode: str = 'r', encoding: str | None = None
+        file_path: str, mode: str = "r", encoding: str | None = None
 ) -> codecs.StreamReaderWriter:
-    if encoding is None and (mode and 'r' in mode):
+    if encoding is None and (mode and "r" in mode):
         encoding = detect_bom_type(file_path)
     if encoding:
         return codecs.open(
-            file_path, mode, errors='ignore', encoding=encoding
+            file_path, mode, errors="ignore", encoding=encoding
         )
     return codecs.open(
-        file_path, mode, errors='ignore'
+        file_path, mode, errors="ignore"
     )
 
 
@@ -349,36 +357,17 @@ def remove_dir(dir_path: str) -> None:
     try:
         shutil.rmtree(dir_path)
     except PermissionError:
-        interactive_spawn(sudo(['rm', '-rf', dir_path]))
-
-
-ChunkT = TypeVar('ChunkT')
-
-
-def get_chunks(iterable: Iterable[ChunkT], chunk_size: int) -> Iterable[list[ChunkT]]:
-    if chunk_size < 1:
-        raise ValueError("`chunk_size` can't be smaller than 1.")
-    result = []
-    index = 0
-    for item in iterable:
-        result.append(item)
-        index += 1
-        if index == chunk_size:
-            yield result
-            result = []
-            index = 0
-    if result:
-        yield result
+        interactive_spawn(sudo(["rm", "-rf", dir_path]))
 
 
 def get_editor() -> list[str] | None:
-    editor_line = os.environ.get('VISUAL') or os.environ.get('EDITOR')
+    editor_line = os.environ.get("VISUAL") or os.environ.get("EDITOR")
     if editor_line:
-        return editor_line.split(' ')
+        return editor_line.split(" ")
     for editor in (
-            'vim', 'nano', 'mcedit', 'edit', 'emacs', 'nvim', 'kak',
-            'e3', 'atom', 'adie', 'dedit', 'gedit', 'jedit', 'kate', 'kwrite', 'leafpad',
-            'mousepad', 'notepadqq', 'pluma', 'code', 'xed', 'nvim-qt', 'geany',
+            "vim", "nano", "mcedit", "edit", "emacs", "nvim", "kak",
+            "e3", "atom", "adie", "dedit", "gedit", "jedit", "kate", "kwrite", "leafpad",
+            "mousepad", "notepadqq", "pluma", "code", "xed", "nvim-qt", "geany",
     ):
         path = shutil.which(editor)
         if path:
@@ -387,10 +376,10 @@ def get_editor() -> list[str] | None:
 
 
 def dirname(path: str) -> str:
-    return os.path.dirname(path) or '.'
+    return os.path.dirname(path) or "."
 
 
-def sudo_loop(once: bool = False) -> None:
+def sudo_loop(*, once: bool = False) -> None:
     """Get sudo for further questions."""
     sudo_loop_interval = PikaurConfig().misc.SudoLoopInterval.get_int()
     if sudo_loop_interval == -1:
@@ -402,7 +391,7 @@ def sudo_loop(once: bool = False) -> None:
         sleep(sudo_loop_interval)
 
 
-SudoLoopResultT = TypeVar('SudoLoopResultT')
+SudoLoopResultT = TypeVar("SudoLoopResultT")
 
 
 def run_with_sudo_loop(function: Callable[..., SudoLoopResultT]) -> SudoLoopResultT | None:
@@ -426,11 +415,11 @@ def run_with_sudo_loop(function: Callable[..., SudoLoopResultT]) -> SudoLoopResu
 
 def check_systemd_dynamic_users() -> bool:  # pragma: no cover
     try:
-        out = subprocess.check_output(['/usr/sbin/systemd-run', '--version'],  # nosec B603
+        out = subprocess.check_output(["/usr/sbin/systemd-run", "--version"],  # nosec B603
                                       universal_newlines=True)
     except FileNotFoundError:
         return False
-    first_line = out.split('\n', maxsplit=1)[0]
+    first_line = out.split("\n", maxsplit=1)[0]
     version = int(first_line.split(maxsplit=2)[1])
     return version >= 235
 
