@@ -4,20 +4,19 @@ import os
 from typing import TypeVar
 
 from .args import parse_args
-from .config import CONFIG_ROOT
+from .config import _USER_TEMP_ROOT, CONFIG_ROOT
 from .core import open_file, running_as_root
 
-
 ConfigValueType = str | list[str] | None
 ConfigFormat = dict[str, ConfigValueType]
 
 
-FallbackValueT = TypeVar('FallbackValueT')
+FallbackValueT = TypeVar("FallbackValueT")
 
 
 class ConfigReader():
 
-    comment_prefixes = ('#', ';')
+    comment_prefixes = ("#", ";")
 
     _cached_config: dict[str, ConfigFormat] | None = None
     default_config_path: str
@@ -27,15 +26,15 @@ class ConfigReader():
     @classmethod
     def _parse_line(cls, line: str) -> tuple[str | None, ConfigValueType]:
         blank = (None, None, )
-        if line.startswith(' '):
+        if line.startswith(" "):
             return blank
-        if '=' not in line:
+        if "=" not in line:
             return blank
         line = line.strip()
         for comment_prefix in cls.comment_prefixes:
             line, *_comments = line.split(comment_prefix)
 
-        key, _sep, value = line.partition('=')
+        key, _sep, value = line.partition("=")
         key = key.strip()
         value = value.strip()
 
@@ -87,9 +86,9 @@ class MakepkgConfig():
 
     @classmethod
     def get_user_makepkg_path(cls) -> str | None:
-        if cls._user_makepkg_path == 'unset':
+        if cls._user_makepkg_path == "unset":
             possible_paths = [
-                os.path.expanduser('~/.makepkg.conf'),
+                os.path.expanduser("~/.makepkg.conf"),
                 os.path.join(CONFIG_ROOT, "pacman/makepkg.conf"),
             ]
             config_path: str | None = None
@@ -116,16 +115,18 @@ class MakepkgConfig():
             value = ConfigReader.get(key, value, config_path=arg_path)
         if config_path:
             value = ConfigReader.get(key, value, config_path=config_path)
-        return value
+        return value  # noqa: RET504
 
 
-CONFIG_PKGDEST = MakepkgConfig.get('PKGDEST')
-if not isinstance(CONFIG_PKGDEST, str):
-    CONFIG_PKGDEST = None
-PKGDEST: str | None = os.environ.get('PKGDEST', CONFIG_PKGDEST)
-if PKGDEST:
-    PKGDEST = PKGDEST.replace('$HOME', '~')
-    PKGDEST = os.path.expanduser(PKGDEST)
+def get_pkgdest() -> str | None:
+    config_pkgdest = MakepkgConfig.get("PKGDEST")
+    if not isinstance(config_pkgdest, str):
+        config_pkgdest = None
+    pkgdest: str | None = os.environ.get("PKGDEST", config_pkgdest)
+    if pkgdest:
+        pkgdest = pkgdest.replace("$HOME", "~")
+        pkgdest = os.path.expanduser(pkgdest)
+    return pkgdest  # noqa: RET504
 
 
 class MakePkgCommand:
@@ -135,13 +136,15 @@ class MakePkgCommand:
 
     @classmethod
     def _apply_dynamic_users_workaround(cls) -> None:
-        if running_as_root() and PKGDEST and (
-                PKGDEST.startswith('/tmp') or  # nosec B108
-                PKGDEST.startswith('/var/tmp')  # nosec B108
+        pkgdest = get_pkgdest()
+        if running_as_root() and pkgdest and (
+                pkgdest.startswith(_USER_TEMP_ROOT) or
+                pkgdest.startswith("/tmp") or  # nosec B108
+                pkgdest.startswith("/var/tmp")  # nosec B108
         ):
             if not cls._cmd:
                 raise RuntimeError()
-            cls._cmd = ['env', 'PKGDEST='] + cls._cmd
+            cls._cmd = ["env", "PKGDEST="] + cls._cmd
             cls.pkgdest_skipped = True
 
     @classmethod
@@ -149,11 +152,11 @@ class MakePkgCommand:
         if cls._cmd is None:
             args = parse_args()
             makepkg_flags = (
-                args.mflags.split(',') if args.mflags else []
+                args.mflags.split(",") if args.mflags else []
             )
             config_args = (
-                ['--config', args.makepkg_config] if args.makepkg_config else []
+                ["--config", args.makepkg_config] if args.makepkg_config else []
             )
-            cls._cmd = [args.makepkg_path or 'makepkg', ] + makepkg_flags + config_args
+            cls._cmd = [args.makepkg_path or "makepkg", ] + makepkg_flags + config_args
             cls._apply_dynamic_users_workaround()
         return cls._cmd
