@@ -3,8 +3,7 @@
 import fnmatch
 import re
 from abc import ABCMeta, abstractmethod
-from threading import Lock
-from typing import TYPE_CHECKING, Any, Pattern
+from typing import TYPE_CHECKING, Final, Pattern
 
 import pyalpm
 from pycman.config import PacmanConfig as PycmanConfig
@@ -14,29 +13,29 @@ from .config import PikaurConfig
 from .core import DataType, PackageSource, spawn, sudo
 from .exceptions import DependencyError, PackagesNotFoundInRepoError
 from .i18n import translate
+from .lock import FancyLock
 from .pacman_i18n import _p
 from .pprint import color_enabled, create_debug_logger, print_error, print_stderr
 from .prompt import retry_interactive_command, retry_interactive_command_or_exit
 from .version import VersionMatcher
 
-
 if TYPE_CHECKING:
     # pylint: disable=cyclic-import
     from .aur import AURPackageInfo
 
 
-OFFICIAL_REPOS = (
-    'core',
-    'extra',
-    'community',
-    'multilib',
-    'testing',
-    'community-testing',
-    'multilib-testing',
+OFFICIAL_REPOS: Final = (
+    "core",
+    "extra",
+    "community",
+    "multilib",
+    "testing",
+    "community-testing",
+    "multilib-testing",
 )
 
 
-_debug = create_debug_logger('pacman')
+_debug = create_debug_logger("pacman")
 
 
 def create_pacman_pattern(pacman_message: str) -> Pattern[str]:
@@ -55,36 +54,32 @@ def create_pacman_pattern(pacman_message: str) -> Pattern[str]:
     )
 
 
-PATTERN_NOTFOUND = create_pacman_pattern("target not found: %s\n")
-PATTERN_DB_NOTFOUND = create_pacman_pattern("database not found: %s\n")
-
-
 def get_pacman_command(ignore_args: list[str] | None = None) -> list[str]:
     ignore_args = ignore_args or []
     args = parse_args()
     pacman_path = PikaurConfig().misc.PacmanPath.get_str()
     pacman_cmd = [pacman_path, ]
     if color_enabled():
-        pacman_cmd += ['--color=always']
+        pacman_cmd += ["--color=always"]
     else:
-        pacman_cmd += ['--color=never']
+        pacman_cmd += ["--color=never"]
 
     for _short, arg, _default in PACMAN_STR_OPTS:
-        if arg in ['color', ]:  # we force it anyway
+        if arg in ["color", ]:  # we force it anyway
             continue
         if arg in ignore_args:
             continue
         value = getattr(args, arg)
         if value:
-            pacman_cmd += ['--' + arg, value]
+            pacman_cmd += ["--" + arg, value]
 
     for _short, arg, _default in PACMAN_APPEND_OPTS:
-        if arg in ['ignore', ]:  # we reprocess it anyway
+        if arg in ["ignore", ]:  # we reprocess it anyway
             continue
         if arg in ignore_args:
             continue
         for value in getattr(args, arg) or []:
-            pacman_cmd += ['--' + arg, value]
+            pacman_cmd += ["--" + arg, value]
 
     return pacman_cmd
 
@@ -99,7 +94,7 @@ class PacmanPrint(DataType):
 class PacmanConfig(PycmanConfig):
 
     def __init__(self) -> None:
-        super().__init__(conf=parse_args().config or '/etc/pacman.conf')
+        super().__init__(conf=parse_args().config or "/etc/pacman.conf")
 
 
 class ProvidedDependency(DataType):
@@ -110,44 +105,22 @@ class ProvidedDependency(DataType):
     def __repr__(self) -> str:
         return (
             f'<{self.__class__.__name__} "{self.name}" '
-            f'{self.version_matcher.line}>'
+            f"{self.version_matcher.line}>"
         )
 
 
-def get_pkg_id(pkg: 'AURPackageInfo | pyalpm.Package') -> str:
+def get_pkg_id(pkg: "AURPackageInfo | pyalpm.Package") -> str:
     if isinstance(pkg, pyalpm.Package):
         return f"{pkg.db.name}/{pkg.name}"
     return f"aur/{pkg.name}"
 
 
-DB_LOCK_REPO = Lock()
-DB_LOCK_LOCAL = Lock()
+class DbLockRepo(FancyLock):
+    pass
 
 
-class DbLockRepo():
-
-    def __enter__(self) -> None:
-        DB_LOCK_REPO.acquire()
-
-    def __exit__(self, *_exc_details: Any) -> None:
-        if DB_LOCK_REPO.locked():
-            DB_LOCK_REPO.release()
-
-    def __del__(self) -> None:
-        self.__exit__()
-
-
-class DbLockLocal():
-
-    def __enter__(self) -> None:
-        DB_LOCK_LOCAL.acquire()
-
-    def __exit__(self, *_exc_details: Any) -> None:
-        if DB_LOCK_LOCAL.locked():
-            DB_LOCK_LOCAL.release()
-
-    def __del__(self) -> None:
-        self.__exit__()
+class DbLockLocal(FancyLock):
+    pass
 
 
 def get_db_lock(package_source: PackageSource) -> type[DbLockRepo] | type[DbLockLocal]:
@@ -177,15 +150,17 @@ class PackageDBCommon(metaclass=ABCMeta):
 
     @classmethod
     def discard_local_cache(cls) -> None:
+        _debug("Discarding local cache...")
         cls._discard_cache(PackageSource.LOCAL)
 
     @classmethod
     def discard_repo_cache(cls) -> None:
+        _debug("Discarding repo cache...")
         cls._discard_cache(PackageSource.REPO)
 
     @classmethod
     @abstractmethod
-    def get_repo_list(cls, quiet: bool = False) -> list[pyalpm.Package]:
+    def get_repo_list(cls, *, quiet: bool = False) -> list[pyalpm.Package]:  # pragma: no cover
         pass
         # if not cls._packages_list_cache.get(PackageSource.REPO):
             # cls._packages_list_cache[PackageSource.REPO] = list(
@@ -195,7 +170,7 @@ class PackageDBCommon(metaclass=ABCMeta):
 
     @classmethod
     @abstractmethod
-    def get_local_list(cls, quiet: bool = False) -> list[pyalpm.Package]:
+    def get_local_list(cls, *, quiet: bool = False) -> list[pyalpm.Package]:  # pragma: no cover
         pass
         # if not cls._packages_list_cache.get(PackageSource.LOCAL):
             # cls._packages_list_cache[PackageSource.LOCAL] = list(
@@ -204,7 +179,7 @@ class PackageDBCommon(metaclass=ABCMeta):
         # return cls._packages_list_cache[PackageSource.LOCAL]
 
     @classmethod
-    def get_repo_dict(cls, quiet: bool = False) -> dict[str, pyalpm.Package]:
+    def get_repo_dict(cls, *, quiet: bool = False) -> dict[str, pyalpm.Package]:
         if not cls._packages_dict_cache.get(PackageSource.REPO):
             cls._packages_dict_cache[PackageSource.REPO] = {
                 get_pkg_id(pkg): pkg
@@ -213,7 +188,7 @@ class PackageDBCommon(metaclass=ABCMeta):
         return cls._packages_dict_cache[PackageSource.REPO]
 
     @classmethod
-    def get_local_dict(cls, quiet: bool = False) -> dict[str, pyalpm.Package]:
+    def get_local_dict(cls, *, quiet: bool = False) -> dict[str, pyalpm.Package]:
         if not cls._packages_dict_cache.get(PackageSource.LOCAL):
             cls._packages_dict_cache[PackageSource.LOCAL] = {
                 pkg.name: pkg
@@ -290,7 +265,8 @@ class PackageDB(PackageDBCommon):
         if not cls._alpm_handle:
             cls._alpm_handle = PacmanConfig().initialize_alpm()
         if not cls._alpm_handle:
-            raise Exception("Cannot initialize ALPM")
+            cant_init_alpm = translate("Cannot initialize ALPM")
+            raise Exception(cant_init_alpm)
         return cls._alpm_handle
 
     @classmethod
@@ -311,12 +287,12 @@ class PackageDB(PackageDBCommon):
         return cls.get_alpm_handle().get_localdb().search(search_query)
 
     @classmethod
-    def get_local_list(cls, quiet: bool = False) -> list[pyalpm.Package]:
+    def get_local_list(cls, *, quiet: bool = False) -> list[pyalpm.Package]:
         if not cls._packages_list_cache.get(PackageSource.LOCAL):
             with DbLockLocal():
                 if not quiet:
                     print_stderr(translate("Reading local package database..."))
-                cls._packages_list_cache[PackageSource.LOCAL] = cls.search_local('')
+                cls._packages_list_cache[PackageSource.LOCAL] = cls.search_local("")
         return cls._packages_list_cache[PackageSource.LOCAL]
 
     @classmethod
@@ -324,7 +300,8 @@ class PackageDB(PackageDBCommon):
         """0 is the highest priority."""
         repos = [r.name for r in cls.get_alpm_handle().get_syncdbs()]
         if repo_name not in repos:
-            raise RepositoryNotFoundError(f"'{repo_name}' in {repos}")
+            repo_not_found = f"'{repo_name}' in {repos}"
+            raise RepositoryNotFoundError(repo_not_found)
         return repos.index(repo_name)
 
     @classmethod
@@ -347,11 +324,12 @@ class PackageDB(PackageDBCommon):
             cls,
             search_query: str,
             db_name: str | None = None,
+            *,
             names_only: bool = False,
             exact_match: bool = False,
     ) -> list[pyalpm.Package]:
-        if '/' in search_query:
-            db_name, search_query = search_query.split('/')
+        if "/" in search_query:
+            db_name, search_query = search_query.split("/")
         result = []
         for sync_db in reversed(cls.get_alpm_handle().get_syncdbs()):
             if not db_name or db_name == sync_db.name:
@@ -367,13 +345,13 @@ class PackageDB(PackageDBCommon):
         return list(reversed(result))
 
     @classmethod
-    def get_repo_list(cls, quiet: bool = False) -> list[pyalpm.Package]:
+    def get_repo_list(cls, *, quiet: bool = False) -> list[pyalpm.Package]:
         if not cls._packages_list_cache.get(PackageSource.REPO):
             with DbLockRepo():
                 if not quiet:
                     print_stderr(translate("Reading repository package databases..."))
                 cls._packages_list_cache[PackageSource.REPO] = cls.search_repo(
-                    search_query=''
+                    search_query=""
                 )
         return cls._packages_list_cache[PackageSource.REPO]
 
@@ -391,26 +369,26 @@ class PackageDB(PackageDBCommon):
 
     @classmethod
     def get_print_format_output(
-            cls, cmd_args: list[str], check_deps: bool = True, package_only: bool = False
+            cls, cmd_args: list[str], *, check_deps: bool = True, package_only: bool = False
     ) -> list[PacmanPrint]:
-        cache_index = ' '.join(sorted(cmd_args))
+        cache_index = " ".join(sorted(cmd_args))
         cached_pkg = cls._pacman_find_cache.get(cache_index)
         if cached_pkg is not None:
             return cached_pkg
         results: list[PacmanPrint] = []
-        final_args = cmd_args + ['--print-format', '%r/%n', ]
+        final_args = cmd_args + ["--print-format", "%r/%n", ]
         if not check_deps and not package_only:
-            final_args.append('--nodeps')
+            final_args.append("--nodeps")
         if package_only:
-            final_args += ['--nodeps', '--nodeps']
+            final_args += ["--nodeps", "--nodeps"]
         proc = spawn(final_args)
         if proc.returncode != 0:
-            raise DependencyError((proc.stderr_text or '') + (proc.stdout_text or ''))
+            raise DependencyError((proc.stderr_text or "") + (proc.stdout_text or ""))
         found_packages_output = proc.stdout_text
         if found_packages_output:
             for line in found_packages_output.splitlines():
                 try:
-                    repo_name, pkg_name = line.split('/')
+                    repo_name, pkg_name = line.split("/")
                 except ValueError:
                     print_stderr(line)
                     continue
@@ -427,16 +405,16 @@ class PackageDB(PackageDBCommon):
     def get_pacman_test_output(cls, cmd_args: list[str]) -> list[VersionMatcher]:
         if not cmd_args:
             return []
-        cache_index = ' '.join(sorted(cmd_args))
-        cached_pkg = cls._pacman_test_cache.get(cache_index)
-        if cached_pkg is not None:
-            return cached_pkg
+        cache_index = " ".join(sorted(cmd_args))
+        cached_pkgs = cls._pacman_test_cache.get(cache_index)
+        if cached_pkgs is not None:
+            return cached_pkgs
         results: list[VersionMatcher] = []
         not_found_packages_output = spawn(
             # pacman --deptest flag conflicts with some --sync options:
             get_pacman_command(ignore_args=[
-                'overwrite'
-            ]) + ['--deptest', ] + cmd_args
+                "overwrite"
+            ]) + ["--deptest", ] + cmd_args
         ).stdout_text
         if not not_found_packages_output:
             cls._pacman_test_cache[cache_index] = results
@@ -449,10 +427,15 @@ class PackageDB(PackageDBCommon):
                 continue
             else:
                 results.append(version_matcher)
+        cls._pacman_test_cache[cache_index] = results
         return results
 
     @classmethod
     def get_not_found_repo_packages(cls, pkg_lines: list[str]) -> list[str]:
+
+        pattern_notfound = create_pacman_pattern("target not found: %s\n")
+        pattern_db_notfound = create_pacman_pattern("database not found: %s\n")
+
         not_found_pkg_names = []
         pkg_names_to_check: list[str] = []
         for pkg_name in pkg_lines:
@@ -460,20 +443,20 @@ class PackageDB(PackageDBCommon):
                 if not cls._pacman_repo_pkg_present_cache[pkg_name]:
                     not_found_pkg_names.append(pkg_name)
             else:
-                pkg_names_to_check += pkg_name.split(',')
+                pkg_names_to_check += pkg_name.split(",")
 
         if not pkg_names_to_check:
             return not_found_pkg_names
 
         results = (
             spawn(
-                get_pacman_command() + ['--sync', '--print-format=%%', '--nodeps'] +
+                get_pacman_command() + ["--sync", "--print-format=%%", "--nodeps"] +
                 pkg_names_to_check
-            ).stderr_text or ''
+            ).stderr_text or ""
         ).splitlines()
         new_not_found_pkg_names = []
         for result in results:
-            for pattern in (PATTERN_NOTFOUND, PATTERN_DB_NOTFOUND, ):
+            for pattern in (pattern_notfound, pattern_db_notfound, ):
                 groups = pattern.findall(result)
                 if groups:
                     pkg_name = VersionMatcher(groups[0]).pkg_name
@@ -488,13 +471,12 @@ class PackageDB(PackageDBCommon):
     def get_not_found_local_packages(cls, pkg_lines: list[str]) -> list[str]:
         not_found_version_matchers = cls.get_pacman_test_output([
             splitted_pkg_name for splitted_pkg_names in
-            [pkg_name.split(',') for pkg_name in pkg_lines]
+            [pkg_name.split(",") for pkg_name in pkg_lines]
             for splitted_pkg_name in splitted_pkg_names
         ])
-        not_found_packages = list({
+        return list({
             vm.pkg_name for vm in not_found_version_matchers
         })
-        return not_found_packages
 
     @classmethod
     def find_repo_package(cls, pkg_name: str) -> pyalpm.Package:
@@ -504,7 +486,7 @@ class PackageDB(PackageDBCommon):
         all_repo_pkgs = PackageDB.get_repo_dict()
         try:
             results = cls.get_print_format_output(
-                get_pacman_command() + ['--sync'] + pkg_name.split(','),
+                get_pacman_command() + ["--sync"] + pkg_name.split(","),
                 package_only=True
             )
         except DependencyError as exc:
@@ -528,7 +510,7 @@ class PackageDB(PackageDBCommon):
 
 def get_upgradeable_package_names() -> list[str]:
     upgradeable_packages_output = spawn(
-        get_pacman_command() + ['--query', '--upgrades', '--quiet']
+        get_pacman_command() + ["--query", "--upgrades", "--quiet"]
     ).stdout_text
     if not upgradeable_packages_output:
         return []
@@ -546,16 +528,16 @@ def find_upgradeable_packages() -> list[pyalpm.Package]:
     results: list[PacmanPrint] = []
     try:
         results = PackageDB.get_print_format_output(
-            get_pacman_command() + ['--sync'] + pkg_names
+            get_pacman_command() + ["--sync"] + pkg_names
         )
     except DependencyError as exc:
         print_error(translate("Dependencies can't be satisfied for the following packages:"))
-        print_stderr(' ' * 12 + ' '.join(pkg_names))
+        print_stderr(" " * 12 + " ".join(pkg_names))
         print_stderr(str(exc))
         for pkg_name in pkg_names:
             try:
                 results += PackageDB.get_print_format_output(
-                    get_pacman_command() + ['--sync'] + [pkg_name, ]
+                    get_pacman_command() + ["--sync"] + [pkg_name, ]
                 )
             except DependencyError as exc2:
                 print_error(translate("Because of:"))
@@ -571,13 +553,13 @@ def find_sysupgrade_packages(ignore_pkgs: list[str] | None = None) -> list[pyalp
 
     extra_args: list[str] = []
     for excluded_pkg_name in ignore_pkgs or []:
-        extra_args.append('--ignore')
+        extra_args.append("--ignore")
         # pacman's --ignore doesn't work with repo name:
         extra_args.append(strip_repo_name(excluded_pkg_name))
 
     results = PackageDB.get_print_format_output(
-        get_pacman_command() + ['--sync'] +
-        ['--sysupgrade'] * parse_args().sysupgrade +
+        get_pacman_command() + ["--sync"] +
+        ["--sysupgrade"] * parse_args().sysupgrade +
         extra_args
     )
     return [
@@ -599,7 +581,7 @@ def refresh_pkg_db_if_needed() -> None:
     args = parse_args()
     if args.refresh:
         pacman_args = (sudo(
-            get_pacman_command() + ['--sync'] + ['--refresh'] * args.refresh
+            get_pacman_command() + ["--sync"] + ["--refresh"] * args.refresh
         ))
         retry_interactive_command_or_exit(pacman_args)
 
@@ -616,13 +598,13 @@ def install_built_deps(
 
     def _get_pacman_command() -> list[str]:
         return get_pacman_command() + reconstruct_args(args, ignore_args=[
-            'upgrade',
-            'asdeps',
-            'sync',
-            'sysupgrade',
-            'refresh',
-            'ignore',
-            'downloadonly',
+            "upgrade",
+            "asdeps",
+            "sync",
+            "sysupgrade",
+            "refresh",
+            "ignore",
+            "downloadonly",
         ])
 
     explicitly_installed_deps = []
@@ -635,8 +617,8 @@ def install_built_deps(
         deps_upgrade_success = retry_interactive_command(
             sudo(
                 _get_pacman_command() + [
-                    '--upgrade',
-                    '--asdeps',
+                    "--upgrade",
+                    "--asdeps",
                 ] + [
                     path for name, path in deps_names_and_paths.items()
                     if name not in explicitly_installed_deps
@@ -651,7 +633,7 @@ def install_built_deps(
         explicit_upgrade_success = retry_interactive_command(
             sudo(
                 _get_pacman_command() + [
-                    '--upgrade',
+                    "--upgrade",
                 ] + [
                     path for name, path in deps_names_and_paths.items()
                     if name in explicitly_installed_deps
@@ -668,7 +650,7 @@ def install_built_deps(
 
 
 def strip_repo_name(pkg_name: str) -> str:
-    return pkg_name.split('/', 1)[-1]
+    return pkg_name.split("/", 1)[-1]
 
 
 def get_ignored_pkgnames_from_patterns(
