@@ -3,14 +3,14 @@
 import sys
 from datetime import datetime
 from fnmatch import fnmatch
-from typing import TYPE_CHECKING, Iterable, Sequence, TypeVar
+from typing import TYPE_CHECKING, Final, Iterable, Sequence, TypeVar
 
 import pyalpm
 
 from .args import parse_args
 from .aur import AURPackageInfo
 from .config import VERSION, PikaurConfig
-from .core import AURInstallInfo, InstallInfo, PackageSource, RepoInstallInfo
+from .core import DEFAULT_TIMEZONE, AURInstallInfo, InstallInfo, PackageSource, RepoInstallInfo
 from .i18n import translate, translate_many
 from .pacman import OFFICIAL_REPOS, PackageDB
 from .pprint import (
@@ -21,6 +21,7 @@ from .pprint import (
     format_paragraph,
     get_term_width,
     print_stderr,
+    print_stdout,
     print_warning,
 )
 from .version import get_common_version, get_version_diff
@@ -30,21 +31,21 @@ if TYPE_CHECKING:
     from .install_info_fetcher import InstallInfoFetcher
 
 
-GROUP_COLOR = Colors.blue
-REPLACEMENTS_COLOR = ColorsHighlight.cyan
-ORPHANED_COLOR = ColorsHighlight.red
-
-
 AnyPackage = AURPackageInfo | pyalpm.Package
-InstallInfoT = TypeVar('InstallInfoT', bound=InstallInfo)
+InstallInfoT = TypeVar("InstallInfoT", bound=InstallInfo)
 
 
-def print_version(pacman_version: str, pyalpm_version: str, quiet: bool = False) -> None:
+GROUP_COLOR: Final = Colors.blue
+REPLACEMENTS_COLOR: Final = ColorsHighlight.cyan
+ORPHANED_COLOR: Final = ColorsHighlight.red
+
+
+def print_version(pacman_version: str, pyalpm_version: str, *, quiet: bool = False) -> None:
     if quiet:
-        print(f'Pikaur v{VERSION}')
-        print(f'{pacman_version} - pyalpm v{pyalpm_version}')
+        print_stdout(f"Pikaur v{VERSION}")
+        print_stdout(f"{pacman_version} - pyalpm v{pyalpm_version}")
     else:
-        year = str(datetime.now().year)
+        year = str(datetime.now(tz=DEFAULT_TIMEZONE).year)
         sys.stdout.write(r"""
       /:}               _
      /--1             / :}
@@ -60,7 +61,7 @@ def print_version(pacman_version: str, pyalpm_version: str, quiet: bool = False)
 """)
 
 
-def print_not_found_packages(not_found_packages: list[str], repo: bool = False) -> None:
+def print_not_found_packages(not_found_packages: list[str], *, repo: bool = False) -> None:
     num_packages = len(not_found_packages)
     print_warning(
         bold_line(
@@ -94,9 +95,9 @@ class RepoColorGenerator:
 
         cls._init_done = True
         for official_repo_name in OFFICIAL_REPOS:
-            cls.get_next('repo', official_repo_name)
+            cls.get_next("repo", official_repo_name)
         for repo in PackageDB.get_alpm_handle().get_syncdbs():
-            cls.get_next('repo', repo.name)
+            cls.get_next("repo", repo.name)
 
     @classmethod
     def get_next(cls, color_type: str, _id: str) -> int:
@@ -117,15 +118,16 @@ class RepoColorGenerator:
         return cls._cache[color_type][_id]
 
 
-def pretty_format_repo_name(repo_name: str, color: bool = True) -> str:
-    result = f'{repo_name}/'
+def pretty_format_repo_name(repo_name: str, *, color: bool = True) -> str:
+    result = f"{repo_name}/"
     if not color:
         return result
-    return color_line(result, RepoColorGenerator.get_next('repo', repo_name))
+    return color_line(result, RepoColorGenerator.get_next("repo", repo_name))
 
 
 def pretty_format_upgradeable(  # pylint: disable=too-many-statements
         packages_updates: Sequence[InstallInfo],
+        *,
         verbose: bool = False,
         print_repo: bool = False,
         color: bool = True,
@@ -151,10 +153,10 @@ def pretty_format_upgradeable(  # pylint: disable=too-many-statements
     )
 
     def pretty_format(  # pylint:disable=too-many-locals,R0912
-            pkg_update: 'InstallInfo'
+            pkg_update: "InstallInfo"
     ) -> tuple[str, type_sort_key]:
         common_version, diff_weight = get_common_version(
-            pkg_update.current_version or '', pkg_update.new_version or ''
+            pkg_update.current_version or "", pkg_update.new_version or ""
         )
         user_config = PikaurConfig()
         color_config = user_config.colors
@@ -168,11 +170,11 @@ def pretty_format_upgradeable(  # pylint: disable=too-many-statements
             pkg_update.name
         )
         user_chosen_sorting = user_config.sync.UpgradeSorting
-        if user_chosen_sorting == 'pkgname':
+        if user_chosen_sorting == "pkgname":
             sort_by = pkg_update.name
-        elif user_chosen_sorting == 'repo':
+        elif user_chosen_sorting == "repo":
             sort_by = (
-                pkg_update.repository or 'zzz_(aur)',
+                pkg_update.repository or "zzz_(aur)",
                 pkg_update.name
             )
 
@@ -181,74 +183,74 @@ def pretty_format_upgradeable(  # pylint: disable=too-many-statements
 
         pkg_name = _bold_line(pkg_name)
         if (print_repo or verbose) and pkg_update.repository:
-            pkg_name = '{}{}'.format(  # pylint: disable=consider-using-f-string
+            pkg_name = "{}{}".format(  # pylint: disable=consider-using-f-string
                 pretty_format_repo_name(pkg_update.repository, color=color),
                 pkg_name
             )
             pkg_len += len(pkg_update.repository) + 1
         elif print_repo:
-            pkg_name = '{}{}'.format(  # pylint: disable=consider-using-f-string
-                _color_line('aur/', ColorsHighlight.red),
+            pkg_name = "{}{}".format(  # pylint: disable=consider-using-f-string
+                _color_line("aur/", ColorsHighlight.red),
                 pkg_name
             )
-            pkg_len += len('aur/')
+            pkg_len += len("aur/")
 
         if pkg_update.required_by:
-            required_by = ' ({})'.format(  # pylint: disable=consider-using-f-string
-                translate('for {pkg}').format(
-                    pkg=', '.join([p.package.name for p in pkg_update.required_by])
+            required_by = " ({})".format(  # pylint: disable=consider-using-f-string
+                translate("for {pkg}").format(
+                    pkg=", ".join([p.package.name for p in pkg_update.required_by])
                 )
             )
             pkg_len += len(required_by)
             dep_color = Colors.yellow
-            required_by = _color_line(' ({})', dep_color).format(
-                translate('for {pkg}').format(
-                    pkg=_color_line(', ', dep_color).join([
+            required_by = _color_line(" ({})", dep_color).format(
+                translate("for {pkg}").format(
+                    pkg=_color_line(", ", dep_color).join([
                         _color_line(p.package.name, dep_color + 8) for p in pkg_update.required_by
-                    ]) + _color_line('', dep_color, reset=False),
+                    ]) + _color_line("", dep_color, reset=False),
                 )
             )
             pkg_name += required_by
         if pkg_update.provided_by:
-            provided_by = ' ({})'.format(  # pylint: disable=consider-using-f-string
-                ' # '.join([p.name for p in pkg_update.provided_by])
+            provided_by = " ({})".format(  # pylint: disable=consider-using-f-string
+                " # ".join([p.name for p in pkg_update.provided_by])
             )
             pkg_len += len(provided_by)
             pkg_name += _color_line(provided_by, Colors.green)
         if pkg_update.members_of:
-            members_of = ' ({})'.format(  # pylint: disable=consider-using-f-string
-                translate_many('{grp} group', '{grp} groups', len(pkg_update.members_of)).format(
-                    grp=', '.join(g for g in pkg_update.members_of),
+            members_of = " ({})".format(  # pylint: disable=consider-using-f-string
+                translate_many("{grp} group", "{grp} groups", len(pkg_update.members_of)).format(
+                    grp=", ".join(g for g in pkg_update.members_of),
                 )
             )
             pkg_len += len(members_of)
-            members_of = _color_line(' ({})', GROUP_COLOR).format(
-                translate_many('{grp} group', '{grp} groups', len(pkg_update.members_of)).format(
-                    grp=_color_line(', ', GROUP_COLOR).join(
+            members_of = _color_line(" ({})", GROUP_COLOR).format(
+                translate_many("{grp} group", "{grp} groups", len(pkg_update.members_of)).format(
+                    grp=_color_line(", ", GROUP_COLOR).join(
                         [_color_line(g, GROUP_COLOR + 8) for g in pkg_update.members_of]
-                    ) + _color_line('', GROUP_COLOR, reset=False),
+                    ) + _color_line("", GROUP_COLOR, reset=False),
                 )
             )
             pkg_name += _color_line(members_of, GROUP_COLOR)
         if pkg_update.replaces:
-            replaces = ' (replaces {})'.format(  # pylint: disable=consider-using-f-string
-                ', '.join(g for g in pkg_update.replaces)
+            replaces = " (replaces {})".format(  # pylint: disable=consider-using-f-string
+                ", ".join(g for g in pkg_update.replaces)
             )
             pkg_len += len(replaces)
             pkg_name += _color_line(replaces, REPLACEMENTS_COLOR)
             if not color:
-                pkg_name = f'# {pkg_name}'
+                pkg_name = f"# {pkg_name}"
 
-        pkg_size = ''
+        pkg_size = ""
         if (
                 user_config.sync.ShowDownloadSize.get_bool() and
                 isinstance(pkg_update.package, pyalpm.Package)
         ):
-            pkg_size = f'{pkg_update.package.size/1024/1024:.2f} MiB'
+            pkg_size = f"{pkg_update.package.size/1024/1024:.2f} MiB"
 
-        days_old = ''
+        days_old = ""
         if pkg_update.devel_pkg_age_days:
-            days_old = ' ' + translate('({} days old)').format(pkg_update.devel_pkg_age_days)
+            days_old = " " + translate("({} days old)").format(pkg_update.devel_pkg_age_days)
 
         if (
                 isinstance(pkg_update.package, AURPackageInfo) and
@@ -258,7 +260,7 @@ def pretty_format_upgradeable(  # pylint: disable=too-many-statements
             pkg_len += len(orphaned)
             pkg_name += _color_line(orphaned, ORPHANED_COLOR)
 
-        out_of_date = ''
+        out_of_date = ""
         if (
                 isinstance(pkg_update.package, AURPackageInfo) and
                 pkg_update.package.outofdate is not None
@@ -266,58 +268,61 @@ def pretty_format_upgradeable(  # pylint: disable=too-many-statements
             out_of_date = _color_line(
                 " [{}: {}]".format(  # pylint: disable=consider-using-f-string
                     translate("outofdate"),
-                    datetime.fromtimestamp(pkg_update.package.outofdate).strftime('%Y/%m/%d')
+                    datetime.fromtimestamp(
+                        pkg_update.package.outofdate,
+                        tz=DEFAULT_TIMEZONE
+                    ).strftime("%Y/%m/%d")
                 ),
                 color_config.VersionDiffOld.get_int()
             )
 
         return (
             template or (
-                ' {pkg_name}{spacing}'
-                ' {current_version}{spacing2}'
-                '{version_separator}{new_version}{spacing3}'
-                '{pkg_size}{days_old}{out_of_date}{verbose}'
+                " {pkg_name}{spacing}"
+                " {current_version}{spacing2}"
+                "{version_separator}{new_version}{spacing3}"
+                "{pkg_size}{days_old}{out_of_date}{verbose}"
             )
         ).format(
             pkg_name=pkg_name,
             current_version=(
                 _color_line(common_version, version_color) +
                 _color_line(
-                    get_version_diff(pkg_update.current_version or '', common_version),
+                    get_version_diff(pkg_update.current_version or "", common_version),
                     old_color
                 )
             ),
             new_version=(
                 _color_line(common_version, version_color) +
                 _color_line(
-                    get_version_diff(pkg_update.new_version or '', common_version),
+                    get_version_diff(pkg_update.new_version or "", common_version),
                     new_color
                 )
             ),
             version_separator=(
-                ' -> ' if (pkg_update.current_version or pkg_update.new_version) else ''
+                " -> " if (pkg_update.current_version or pkg_update.new_version) else ""
             ),
-            spacing=' ' * max(1, (column_width - pkg_len)),
-            spacing2=' ' * max(1, (
+            spacing=" " * max(1, (column_width - pkg_len)),
+            spacing2=" " * max(1, (
                 column_width - 18 -
-                len(pkg_update.current_version or '') -
+                len(pkg_update.current_version or "") -
                 max(-1, (pkg_len - column_width))
             )),
-            spacing3=(' ' * max(1, (
+            spacing3=(" " * max(1, (
                 column_width - 18 -
-                len(pkg_update.new_version or '') -
+                len(pkg_update.new_version or "") -
                 max(-1, (pkg_len - column_width))
-            )) if pkg_size else ''),
+            )) if pkg_size else ""),
             pkg_size=pkg_size,
             days_old=days_old,
             out_of_date=out_of_date,
             verbose=(
-                '' if not (verbose and pkg_update.description)
-                else f'\n{format_paragraph(pkg_update.description)}'
+                "" if not (verbose and pkg_update.description)
+                else f"\n{format_paragraph(pkg_update.description)}"
             )
         ), sort_by
 
-    return '\n'.join([
+    return "\n".join([
         line for line, _ in sorted(
             [
                 pretty_format(pkg_update)
@@ -332,10 +337,11 @@ class SysupgradePrettyFormatter:
 
     def __init__(
         self,
-        install_info: 'InstallInfoFetcher',
+        install_info: "InstallInfoFetcher",
+        *,
         verbose: bool,
         manual_package_selection: bool
-    ):
+    ) -> None:
         self.color = True
         self.install_info = install_info
         self.verbose = verbose
@@ -411,15 +417,15 @@ class SysupgradePrettyFormatter:
                         warn_about_packages_list.append(pkg_install_info)
 
         if warn_about_packages_str:
-            globs_and_names = warn_about_packages_str.split(',')
+            globs_and_names = warn_about_packages_str.split(",")
             pkg_list: list[RepoInstallInfo] | list[AURInstallInfo]
             for pkg_list in self.all_install_info_lists:
                 remove_globs_from_pkg_list(pkg_list)  # type: ignore[misc]
 
         if warn_about_packages_list:
-            self.result.append('\n{} {} {} {}'.format(  # pylint: disable=consider-using-f-string
-                self._color_line('::', ColorsHighlight.blue),
-                self._color_line('!!', ColorsHighlight.red),
+            self.result.append("\n{} {} {} {}".format(  # pylint: disable=consider-using-f-string
+                self._color_line("::", ColorsHighlight.blue),
+                self._color_line("!!", ColorsHighlight.red),
                 self._color_line(
                     translate_many(
                         "WARNING about package installation:",
@@ -427,14 +433,14 @@ class SysupgradePrettyFormatter:
                         len(warn_about_packages_list)
                     ), ColorsHighlight.red
                 ),
-                self._color_line('!!', ColorsHighlight.red),
+                self._color_line("!!", ColorsHighlight.red),
             ))
             self.result.append(self.pretty_format_upgradeable(warn_about_packages_list))
 
     def pformat_replacements(self) -> None:
         if self.repo_replacements:
-            self.result.append('\n{} {}'.format(  # pylint: disable=consider-using-f-string
-                self._color_line('::', ColorsHighlight.blue),
+            self.result.append("\n{} {}".format(  # pylint: disable=consider-using-f-string
+                self._color_line("::", ColorsHighlight.blue),
                 self._bold_line(translate_many(
                     "Repository package suggested as a replacement:",
                     "Repository packages suggested as a replacement:",
@@ -444,8 +450,8 @@ class SysupgradePrettyFormatter:
                 self.repo_replacements,
             ))
         if self.thirdparty_repo_replacements:
-            self.result.append('\n{} {}'.format(  # pylint: disable=consider-using-f-string
-                self._color_line('::', ColorsHighlight.blue),
+            self.result.append("\n{} {}".format(  # pylint: disable=consider-using-f-string
+                self._color_line("::", ColorsHighlight.blue),
                 self._bold_line(translate_many(
                     "Third-party repository package suggested as a replacement:",
                     "Third-party repository packages suggested as a replacement:",
@@ -457,8 +463,8 @@ class SysupgradePrettyFormatter:
 
     def pformat_repo(self) -> None:
         if self.repo_packages_updates:
-            self.result.append('\n{} {}'.format(  # pylint: disable=consider-using-f-string
-                self._color_line('::', ColorsHighlight.blue),
+            self.result.append("\n{} {}".format(  # pylint: disable=consider-using-f-string
+                self._color_line("::", ColorsHighlight.blue),
                 self._bold_line(translate_many(
                     "Repository package will be installed:",
                     "Repository packages will be installed:",
@@ -468,8 +474,8 @@ class SysupgradePrettyFormatter:
                 self.repo_packages_updates,
             ))
         if self.new_repo_deps:
-            self.result.append('\n{} {}'.format(  # pylint: disable=consider-using-f-string
-                self._color_line('::', ColorsHighlight.yellow),
+            self.result.append("\n{} {}".format(  # pylint: disable=consider-using-f-string
+                self._color_line("::", ColorsHighlight.yellow),
                 self._bold_line(translate_many(
                     "New dependency will be installed from repository:",
                     "New dependencies will be installed from repository:",
@@ -482,8 +488,8 @@ class SysupgradePrettyFormatter:
 
     def pformat_thirdaprty_repo(self) -> None:
         if self.thirdparty_repo_packages_updates:
-            self.result.append('\n{} {}'.format(  # pylint: disable=consider-using-f-string
-                self._color_line('::', ColorsHighlight.blue),
+            self.result.append("\n{} {}".format(  # pylint: disable=consider-using-f-string
+                self._color_line("::", ColorsHighlight.blue),
                 self._bold_line(translate_many(
                     "Third-party repository package will be installed:",
                     "Third-party repository packages will be installed:",
@@ -495,8 +501,8 @@ class SysupgradePrettyFormatter:
                 print_repo=True
             ))
         if self.new_thirdparty_repo_deps:
-            self.result.append('\n{} {}'.format(  # pylint: disable=consider-using-f-string
-                self._color_line('::', ColorsHighlight.yellow),
+            self.result.append("\n{} {}".format(  # pylint: disable=consider-using-f-string
+                self._color_line("::", ColorsHighlight.yellow),
                 self._bold_line(translate_many(
                     "New dependency will be installed from third-party repository:",
                     "New dependencies will be installed from third-party repository:",
@@ -509,8 +515,8 @@ class SysupgradePrettyFormatter:
 
     def pformat_aur(self) -> None:
         if self.aur_updates:
-            self.result.append('\n{} {}'.format(  # pylint: disable=consider-using-f-string
-                self._color_line('::', ColorsHighlight.cyan),
+            self.result.append("\n{} {}".format(  # pylint: disable=consider-using-f-string
+                self._color_line("::", ColorsHighlight.cyan),
                 self._bold_line(translate_many(
                     "AUR package will be installed:",
                     "AUR packages will be installed:",
@@ -522,8 +528,8 @@ class SysupgradePrettyFormatter:
                 print_repo=False
             ))
         if self.new_aur_deps:
-            self.result.append('\n{} {}'.format(  # pylint: disable=consider-using-f-string
-                self._color_line('::', ColorsHighlight.yellow),
+            self.result.append("\n{} {}".format(  # pylint: disable=consider-using-f-string
+                self._color_line("::", ColorsHighlight.yellow),
                 self._bold_line(translate_many(
                     "New dependency will be installed from AUR:",
                     "New dependencies will be installed from AUR:",
@@ -538,16 +544,16 @@ class SysupgradePrettyFormatter:
     def pformat_total_size(self) -> None:
         if self.config.sync.ShowDownloadSize.get_bool():
             self.result.append(
-                '\n' +
+                "\n" +
                 self._bold_line(translate("Total Download Size:")) +
-                f'{str(round(self.install_info.get_total_download_size(), 2)).rjust(10)} MiB'
-                '\n' +
+                f"{str(round(self.install_info.get_total_download_size(), 2)).rjust(10)} MiB"
+                "\n" +
                 self._bold_line(translate("Total Installed Size:")) +
-                f'{str(round(self.install_info.get_total_installed_size(), 2)).rjust(9)} MiB'
-                '\n'
+                f"{str(round(self.install_info.get_total_installed_size(), 2)).rjust(9)} MiB"
+                "\n"
             )
         else:
-            self.result += ['']
+            self.result += [""]
 
     def __call__(self) -> str:
         self.pformat_warned_packages()
@@ -556,11 +562,12 @@ class SysupgradePrettyFormatter:
         self.pformat_thirdaprty_repo()
         self.pformat_aur()
         self.pformat_total_size()
-        return '\n'.join(self.result)
+        return "\n".join(self.result)
 
 
 def pretty_format_sysupgrade(
-        install_info: 'InstallInfoFetcher',
+        install_info: "InstallInfoFetcher",
+        *,
         verbose: bool = False,
         manual_package_selection: bool = False
 ) -> str:
@@ -577,15 +584,21 @@ def print_ignored_package(
         ignored_from: str | None = None
 ) -> None:
     if not (package_name or install_info):
-        raise TypeError("Either 'package_name' or 'install_info' should be specified")
+        missing_property_error = translate(
+            "Either `{prop1}` or `{prop2}` should be set"
+        ).format(
+            prop1="package_name",
+            prop2="install_info",
+        )
+        raise TypeError(missing_property_error)
     install_info = install_info or InstallInfo(
         name=package_name,
-        current_version='',
-        new_version='',
+        current_version="",
+        new_version="",
         package=None,
     )
-    message = '{} {}'.format(  # pylint: disable=consider-using-f-string
-        color_line('::', ColorsHighlight.yellow),
+    message = "{} {}".format(  # pylint: disable=consider-using-f-string
+        color_line("::", ColorsHighlight.yellow),
         translate("Ignoring package update {}").format(
             pretty_format_upgradeable(
                 [install_info],
@@ -657,6 +670,7 @@ def print_package_search_results(
         repo_packages: Iterable[pyalpm.Package],
         aur_packages: Iterable[AURPackageInfo],
         local_pkgs_versions: dict[str, str],
+        *,
         enumerated: bool = False,
 ) -> list[AnyPackage]:
 
@@ -680,13 +694,13 @@ def print_package_search_results(
         pkg_numvotes = pkg.numvotes if isinstance(pkg.numvotes, int) else 0
         pkg_popularity = pkg.popularity if isinstance(pkg.popularity, float) else 0.0
 
-        if user_aur_sort == 'pkgname':
+        if user_aur_sort == "pkgname":
             return (-1.0, pkg.name)
-        if user_aur_sort == 'popularity':
+        if user_aur_sort == "popularity":
             return ((-pkg_popularity, -pkg_numvotes), pkg.name)
-        if user_aur_sort == 'numvotes':
+        if user_aur_sort == "numvotes":
             return ((-pkg_numvotes, -pkg_popularity), pkg.name)
-        if user_aur_sort == 'lastmodified':
+        if user_aur_sort == "lastmodified":
             return (
                 -pkg.lastmodified
                 if isinstance(pkg.lastmodified, int)
@@ -714,41 +728,41 @@ def print_package_search_results(
 
     for pkg_idx, package in enumerated_packages:
         # @TODO: return only packages for the current architecture
-        idx = ''
+        idx = ""
         if enumerated:
-            idx = bold_line(f'{pkg_idx+1}) ')
+            idx = bold_line(f"{pkg_idx+1}) ")
 
         pkg_name = package.name
         if args.quiet:
-            print(f'{idx}{pkg_name}')
+            print_stdout(f"{idx}{pkg_name}")
         else:
 
-            repo = color_line('aur/', ColorsHighlight.red)
+            repo = color_line("aur/", ColorsHighlight.red)
             if isinstance(package, pyalpm.Package):
                 repo = pretty_format_repo_name(package.db.name)
 
-            groups = ''
-            if getattr(package, 'groups', None):
-                groups = color_line('({}) '.format(  # pylint: disable=consider-using-f-string
-                    ' '.join(package.groups)
+            groups = ""
+            if getattr(package, "groups", None):
+                groups = color_line("({}) ".format(  # pylint: disable=consider-using-f-string
+                    " ".join(package.groups)
                 ), GROUP_COLOR)
 
-            installed = ''
+            installed = ""
             if pkg_name in local_pkgs_names:
                 if package.version != local_pkgs_versions[pkg_name]:
                     installed = color_line(
                         translate("[installed: {version}]").format(
                             version=local_pkgs_versions[pkg_name],
-                        ) + ' ',
+                        ) + " ",
                         ColorsHighlight.cyan
                     )
                 else:
                     installed = color_line(
-                        translate("[installed]") + ' ',
+                        translate("[installed]") + " ",
                         ColorsHighlight.cyan
                     )
 
-            rating = ''
+            rating = ""
             if (
                     isinstance(package, AURPackageInfo)
             ) and (
@@ -757,7 +771,7 @@ def print_package_search_results(
                 package.popularity is not None
             ):
                 rating = color_line(
-                    f'({package.numvotes}, {package.popularity:.2f})',
+                    f"({package.numvotes}, {package.popularity:.2f})",
                     Colors.yellow
                 )
 
@@ -770,7 +784,10 @@ def print_package_search_results(
                 version = "{} [{}: {}]".format(  # pylint: disable=consider-using-f-string
                     package.version,
                     translate("outofdate"),
-                    datetime.fromtimestamp(package.outofdate).strftime('%Y/%m/%d')
+                    datetime.fromtimestamp(
+                        package.outofdate,
+                        tz=DEFAULT_TIMEZONE
+                    ).strftime("%Y/%m/%d")
                 )
 
             last_updated = ""
@@ -783,15 +800,18 @@ def print_package_search_results(
                     last_update_date = package.lastmodified
 
                 last_updated = color_line(
-                    ' (last updated: {})'.format(  # pylint: disable=consider-using-f-string
-                        datetime.fromtimestamp(last_update_date).strftime('%Y/%m/%d')
+                    " (last updated: {})".format(  # pylint: disable=consider-using-f-string
+                        datetime.fromtimestamp(
+                            last_update_date,
+                            tz=DEFAULT_TIMEZONE
+                        ).strftime("%Y/%m/%d")
                         if last_update_date is not None
-                        else 'unknown'
+                        else "unknown"
                     ),
                     ColorsHighlight.black
                 )
 
-            print("{}{}{} {} {}{}{}{}".format(  # pylint: disable=consider-using-f-string
+            print_stdout("{}{}{} {} {}{}{}{}".format(  # pylint: disable=consider-using-f-string
                 idx,
                 repo,
                 bold_line(pkg_name),
@@ -801,5 +821,5 @@ def print_package_search_results(
                 rating,
                 last_updated
             ))
-            print(format_paragraph(f'{package.desc}'))
+            print_stdout(format_paragraph(f"{package.desc}"))
     return sorted_packages
