@@ -1,14 +1,14 @@
 """Licensed under GPLv3, see https://www.gnu.org/licenses/"""
 
 from datetime import datetime
-from typing import Sequence
+from typing import Final, Sequence
 
 import pyalpm
 
 from .args import parse_args
 from .aur import AURPackageInfo, find_aur_packages
 from .config import PikaurConfig
-from .core import AURInstallInfo, InstallInfo, RepoInstallInfo
+from .core import DEFAULT_TIMEZONE, AURInstallInfo, InstallInfo, RepoInstallInfo
 from .exceptions import PackagesNotFoundInRepoError
 from .i18n import translate, translate_many
 from .pacman import (
@@ -26,14 +26,13 @@ from .print_department import (
 )
 from .version import compare_versions
 
-
-DEVEL_PKGS_POSTFIXES = (
-    '-git',
-    '-svn',
-    '-bzr',
-    '-hg',
-    '-cvs',
-    '-nightly',
+DEVEL_PKGS_POSTFIXES: Final = (
+    "-git",
+    "-svn",
+    "-bzr",
+    "-hg",
+    "-cvs",
+    "-nightly",
 )
 
 
@@ -95,7 +94,7 @@ def find_aur_devel_updates(
         package_ttl_days: int
 ) -> list[AURInstallInfo]:
     local_packages = PackageDB.get_local_dict()
-    now = datetime.now()
+    now = datetime.now(tz=DEFAULT_TIMEZONE)
     aur_updates = []
     for aur_pkg in sorted(aur_pkgs_info, key=lambda x: x.name):
         pkg_name = aur_pkg.name
@@ -103,14 +102,14 @@ def find_aur_devel_updates(
             continue
         local_pkg = local_packages[pkg_name]
         pkg_install_datetime = datetime.fromtimestamp(
-            local_pkg.installdate
+            local_pkg.installdate, tz=DEFAULT_TIMEZONE
         )
         pkg_age_days = (now - pkg_install_datetime).days
         if pkg_age_days >= package_ttl_days:
             aur_updates.append(AURInstallInfo(
                 name=pkg_name,
                 current_version=local_pkg.version,
-                new_version='devel',
+                new_version="devel",
                 description=aur_pkg.desc,
                 devel_pkg_age_days=pkg_age_days,
                 maintainer=aur_pkg.maintainer,
@@ -165,8 +164,9 @@ def find_aur_updates() -> tuple[list[AURInstallInfo], list[str]]:
 
 
 def print_upgradeable(
+        aur_install_infos: Sequence[InstallInfo] | None = None,
+        *,
         ignored_only: bool = False,
-        aur_install_infos: Sequence[InstallInfo] | None = None
 ) -> None:
     args = parse_args()
     updates: list[InstallInfo] = []
@@ -186,7 +186,7 @@ def print_upgradeable(
     )
     config_ignored_pkg_names = get_ignored_pkgnames_from_patterns(
         pkg_names,
-        PacmanConfig().options.get('IgnorePkg', [])
+        PacmanConfig().options.get("IgnorePkg", [])
     )
     ignored_pkg_names = manually_ignored_pkg_names + config_ignored_pkg_names
     for pkg in updates[:]:
@@ -199,7 +199,7 @@ def print_upgradeable(
     if ignored_only:
         return
     if args.quiet:
-        print_stdout('\n'.join([
+        print_stdout("\n".join([
             pkg_update.name for pkg_update in updates
         ]))
     else:
